BasisuEncoderParams

Struct BasisuEncoderParams 

pub struct BasisuEncoderParams {
    pub basis_tex_format: BasisTextureFormat,
    pub quality_level: i32,
    pub effort_level: i32,
    pub flags_and_quality: u64,
    pub low_level_uastc_rdo_or_dct_quality: f32,
}
Available on crate features encoder and extra only.

Fields

basis_tex_format: BasisTextureFormat

Target file format — one of the BTF_* constants (e.g. BTF_ETC1S, BTF_UASTC_LDR_4X4).

quality_level: i32

Unified Quality level [1, 100]. See common::BU_QUALITY_MIN, common::BU_QUALITY_MAX. Note the recommended usable unified quality range is [1, 100], but the C API accepts [0, 100]. Use -1 to use older non-unified/direct codec-specific quality level or lambda (low 8-bits of flags_and_quality, or via low_level_uastc_rdo_or_dct_quality).

effort_level: i32

Unified Encoder effort [0, 10]. See common::BU_EFFORT_MIN, common::BU_EFFORT_MAX. See BU_EFFORT_* presets. Use -1 to use older non-unified/direct codec-specific effort level (low 8-bits of flags_and_quality for some codecs).

flags_and_quality: u64

Bitwise OR of BU_COMP_FLAGS_* constants. Controls output format, mipmaps, color space, etc. Low 8-bits are either the older non-unified quality level, or for some codecs the non-unified effort level.

low_level_uastc_rdo_or_dct_quality: f32

Low-level (non-unified) quality or lambda parameter for UASTC RDO encoding. Typically 0.0 for defaults. Must be 0.0 if using unified (not -1) quality level.

Implementations

Source

impl BasisuEncoderParams

pub const fn new_with_srgb_defaults( basis_tex_format: BasisTextureFormat, ) -> Self

pub const fn new_with_linear_defaults( basis_tex_format: BasisTextureFormat, ) -> Self

pub const fn with_tex_type(self, tex_type: TextureViewDimension) -> Self

Return Self with common::BU_COMP_FLAGS_TEXTURE_TYPE_* set according to the view dimension.

Panic if the view dimension is D1 or D3.

pub const fn with_flags(self, flags: u64) -> Self

Bitwise OR the flags (See BU_COMP_FLAGS_*) to self.